@@ -1,7 +1,7 @@
 import logging
 
 from .router import router
-from .rules import front_door_allows_request
+from .rules import front_door_check_access
 from .utils import get_client_ip
 
 logger = logging.getLogger(__name__)
@@ -14,7 +14,7 @@ class FrontDoorMiddleware:
     def __call__(self, request):
         ip = get_client_ip(request)
         request.user_ip = ip
-        if front_door_allows_request(request):
+        if front_door_check_access(request):
             response = self.get_response(request)
         else:
             response = router.route(request)
