@@ -67,5 +67,7 @@ def front_door_check_access(request):
             except FrontDoorClosed:
                 logger_denied.debug(f"FrontDoor access FORBIDDEN by '{check.__name__}()' to {path}")
                 return False
+        if not access_allowed:
+            logger_denied.error(f"FrontDoor access DENIED to {path}", ip=ip, path=path)
 
     return access_allowed
