@@ -29,3 +29,7 @@ def get_client_ip(request: HttpRequest):
 
 def parse_bool(value):
     return value in [True, "True", "true", "T", "1", 1, "y", "Y"]
+
+
+def parse_policy(value):
+    return value in [True, "True", "true", "T", "1", 1, "y", "Y", "allow", "open"]
